aboutsummaryrefslogtreecommitdiff
path: root/examples/gemm_tuner/CommonGemmExampleOptions.h
diff options
context:
space:
mode:
Diffstat (limited to 'examples/gemm_tuner/CommonGemmExampleOptions.h')
-rw-r--r--examples/gemm_tuner/CommonGemmExampleOptions.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/examples/gemm_tuner/CommonGemmExampleOptions.h b/examples/gemm_tuner/CommonGemmExampleOptions.h
index 5c4be286d6..633e9252bd 100644
--- a/examples/gemm_tuner/CommonGemmExampleOptions.h
+++ b/examples/gemm_tuner/CommonGemmExampleOptions.h
@@ -65,9 +65,10 @@ class CommonGemmExampleOptions
public:
/** Constructor
*
* @param[in,out] parser A parser on which "parse()" hasn't been called yet.
*/
- CommonGemmExampleOptions(arm_compute::utils::CommandLineParser &parser);
+ CommonGemmExampleOptions(arm_compute::utils::CommandLineParser &parser, arm_compute::DataType default_data_type = arm_compute::DataType::F32);
/** Prevent instances of this class from being copied (As this class contains pointers) */
CommonGemmExampleOptions(const CommonGemmExampleOptions &) = delete;
/** Prevent instances of this class from being copied (As this class contains pointers) */
@@ -65,9 +65,10 @@ class CommonGemmExampleOptions
/** Constructor
*
- * @param[in,out] parser A parser on which "parse()" hasn't been called yet.
+ * @param[in,out] parser A parser on which "parse()" hasn't been called yet.
+ * @param[in] default_data_type Default data type if unspecified.
*/